@@ -1329,6 +1329,7 @@ enum {
 
   MZCONFIG_ERROR_DISPLAY_HANDLER,
   MZCONFIG_ERROR_PRINT_VALUE_HANDLER,
+  MZCONFIG_ERROR_PRINT_SYNTAX_HANDLER,
 
   MZCONFIG_EXIT_HANDLER,
 
@@ -1338,6 +1339,7 @@ enum {
   MZCONFIG_PROMPT_READ_HANDLER,
   MZCONFIG_READ_HANDLER,
   MZCONFIG_READ_INPUT_PORT_HANDLER,
+  MZCONFIG_READ_GET_EVT,
 
   MZCONFIG_CASE_SENS,
   MZCONFIG_CAN_READ_PIPE_QUOTE,
@@ -1407,6 +1409,7 @@ enum {
 
   MZCONFIG_SUBPROC_CUSTODIAN_MODE,
   MZCONFIG_SUBPROC_GROUP_ENABLED,
+  MZCONFIG_SUBPROC_KEEP_FDS,
 
   MZCONFIG_LOAD_DELAY_ENABLED,
   MZCONFIG_DELAY_LOAD_INFO,
