@@ -197,13 +197,14 @@ MZ_EXTERN Scheme_On_Atomic_Timeout_Proc scheme_set_on_atomic_timeout(Scheme_On_A
 /*                              error handling                            */
 /*========================================================================*/
 
-MZ_EXTERN void scheme_signal_error(const char *msg, ...);
-MZ_EXTERN void scheme_raise_exn(int exnid, ...);
+MZ_EXTERN MZ_NORETURN void scheme_signal_error(const char *msg, ...);
+MZ_EXTERN MZ_NORETURN void scheme_raise_exn(int exnid, ...);
 MZ_EXTERN void scheme_warning(char *msg, ...);
 
 MZ_EXTERN void scheme_raise(Scheme_Object *exn);
 
 MZ_EXTERN int scheme_log_level_p(Scheme_Logger *logger, int level);
+MZ_EXTERN int scheme_log_level_topic_p(Scheme_Logger *logger, int level, Scheme_Object *name);
 MZ_EXTERN void scheme_log(Scheme_Logger *logger, int level, int flags,
                           const char *msg, ...);
 MZ_EXTERN void scheme_log_w_data(Scheme_Logger *logger, int level, int flags,
@@ -221,32 +222,17 @@ MZ_EXTERN void scheme_glib_log_message(const char *log_domain, int log_level, co
 MZ_EXTERN void *scheme_glib_log_message_test(char *str);
 MZ_EXTERN void scheme_out_of_memory_abort();
 
-MZ_EXTERN void scheme_wrong_count(const char *name, int minc, int maxc,
-				  int argc, Scheme_Object **argv);
-MZ_EXTERN void scheme_wrong_count_m(const char *name, int minc, int maxc,
-				    int argc, Scheme_Object **argv,
-				    int is_method);
-MZ_EXTERN void scheme_case_lambda_wrong_count(const char *name, int argc,
-					      Scheme_Object **argv, int is_method, int count, ...);
-MZ_EXTERN void scheme_wrong_type(const char *name, const char *expected,
-				 int which, int argc,
-				 Scheme_Object **argv);
-MZ_EXTERN void scheme_wrong_contract(const char *name, const char *expected,
-                                     int which, int argc,
-                                     Scheme_Object **argv);
-MZ_EXTERN void scheme_wrong_field_type(Scheme_Object *c_name,
-				       const char *expected,
-				       Scheme_Object *o);
-MZ_EXTERN void scheme_wrong_field_contract(Scheme_Object *c_name,
-                                           const char *expected,
-                                           Scheme_Object *o);
-MZ_EXTERN void scheme_arg_mismatch(const char *name, const char *msg, Scheme_Object *o);
-MZ_EXTERN void scheme_contract_error(const char *name, const char *msg, ...);
-MZ_EXTERN void scheme_wrong_return_arity(const char *where,
-					 int expected, int got,
-					 Scheme_Object **argv,
-					 const char *context_detail, ...);
-MZ_EXTERN void scheme_unbound_global(Scheme_Bucket *b);
+MZ_EXTERN MZ_NORETURN void scheme_wrong_count(const char *name, int minc, int maxc, int argc, Scheme_Object **argv);
+MZ_EXTERN MZ_NORETURN void scheme_wrong_count_m(const char *name, int minc, int maxc, int argc, Scheme_Object **argv, int is_method);
+MZ_EXTERN MZ_NORETURN void scheme_case_lambda_wrong_count(const char *name, int argc, Scheme_Object **argv, int is_method, int count, ...);
+MZ_EXTERN MZ_NORETURN void scheme_wrong_type(const char *name, const char *expected, int which, int argc, Scheme_Object **argv);
+MZ_EXTERN MZ_NORETURN void scheme_wrong_contract(const char *name, const char *expected, int which, int argc, Scheme_Object **argv);
+MZ_EXTERN MZ_NORETURN void scheme_wrong_field_type(Scheme_Object *c_name, const char *expected, Scheme_Object *o);
+MZ_EXTERN MZ_NORETURN void scheme_wrong_field_contract(Scheme_Object *c_name, const char *expected, Scheme_Object *o);
+MZ_EXTERN MZ_NORETURN void scheme_arg_mismatch(const char *name, const char *msg, Scheme_Object *o);
+MZ_EXTERN MZ_NORETURN void scheme_contract_error(const char *name, const char *msg, ...);
+MZ_EXTERN MZ_NORETURN void scheme_wrong_return_arity(const char *where, int expected, int got, Scheme_Object **argv, const char *context_detail, ...);
+MZ_EXTERN MZ_NORETURN void scheme_unbound_global(Scheme_Bucket *b);
 
 MZ_EXTERN Scheme_Object *scheme_dynamic_wind(void (*pre)(void *),
 					     Scheme_Object *(* volatile act)(void *),
@@ -494,7 +480,7 @@ MZ_EXTERN void scheme_clear_hash_table(Scheme_Hash_Table *ht);
 XFORM_NONGCING_NONALIASING MZ_EXTERN int scheme_hash_table_index(Scheme_Hash_Table *hash, mzlonglong pos, Scheme_Object **_key, Scheme_Object **_val);
 XFORM_NONGCING MZ_EXTERN Scheme_Object *scheme_hash_table_next(Scheme_Hash_Table *hash, mzlonglong start);
 
-MZ_EXTERN Scheme_Hash_Tree *scheme_make_hash_tree(int kind);
+XFORM_NONGCING MZ_EXTERN Scheme_Hash_Tree *scheme_make_hash_tree(int kind);
 MZ_EXTERN Scheme_Hash_Tree *scheme_hash_tree_set(Scheme_Hash_Tree *tree, Scheme_Object *key, Scheme_Object *val);
 MZ_EXTERN Scheme_Object *scheme_hash_tree_get(Scheme_Hash_Tree *tree, Scheme_Object *key);
 XFORM_NONGCING MZ_EXTERN Scheme_Object *scheme_eq_hash_tree_get(Scheme_Hash_Tree *tree, Scheme_Object *key);
@@ -934,7 +920,7 @@ MZ_EXTERN char *scheme_expand_filename(char* filename, int ilen, const char *err
 MZ_EXTERN char *scheme_expand_user_filename(char* filename, int ilen, const char *errorin, int *ex, int guards);
 MZ_EXTERN char *scheme_expand_string_filename(Scheme_Object *f, const char *errorin, int *ex, int guards);
 
-MZ_EXTERN char *scheme_os_getcwd(char *buf, int buflen, int *actlen, int noexn);
+MZ_EXTERN char *scheme_os_getcwd(char *buf, size_t buflen, int *actlen, int noexn);
 MZ_EXTERN int scheme_os_setcwd(char *buf, int noexn);
 MZ_EXTERN char *scheme_getdrive(void);
 
@@ -1154,17 +1140,17 @@ MZ_EXTERN Scheme_Object *scheme_make_weak_box(Scheme_Object *v);
 MZ_EXTERN Scheme_Object *scheme_make_late_weak_box(Scheme_Object *v);
 
 MZ_EXTERN Scheme_Object *scheme_make_ephemeron(Scheme_Object *key, Scheme_Object *val);
-MZ_EXTERN Scheme_Object *scheme_ephemeron_value(Scheme_Object *o);
-MZ_EXTERN Scheme_Object *scheme_ephemeron_key(Scheme_Object *o);
+XFORM_NONGCING MZ_EXTERN Scheme_Object *scheme_ephemeron_value(Scheme_Object *o);
+XFORM_NONGCING MZ_EXTERN Scheme_Object *scheme_ephemeron_key(Scheme_Object *o);
 
-MZ_EXTERN Scheme_Object *scheme_make_stubborn_will_executor();
+MZ_EXTERN Scheme_Object *scheme_make_late_will_executor();
 
 MZ_EXTERN Scheme_Object *scheme_load(const char *file);
 MZ_EXTERN Scheme_Object *scheme_load_extension(const char *filename, Scheme_Env *env);
 MZ_EXTERN void scheme_register_extension_global(void *ptr, intptr_t size);
 
 MZ_EXTERN intptr_t scheme_get_seconds(void);
-XFORM_NONGCING MZ_EXTERN intptr_t scheme_get_milliseconds(void);
+XFORM_NONGCING MZ_EXTERN uintptr_t scheme_get_milliseconds(void);
 XFORM_NONGCING MZ_EXTERN double scheme_get_inexact_milliseconds(void);
 XFORM_NONGCING MZ_EXTERN intptr_t scheme_get_process_milliseconds(void);
 XFORM_NONGCING MZ_EXTERN intptr_t scheme_get_process_children_milliseconds(void);
